@@ -7,14 +7,17 @@
 
 """
 import logging
-from urllib import urlencode
-from urlparse import parse_qs
+try:
+    from urllib.parse import urlencode, parse_qs
+except ImportError:
+    from urllib import urlencode
+    from urlparse import parse_qs
 from functools import wraps
 
 import requests
 from flask import redirect, request, json
 
-__version__ = '0.3.4'
+__version__ = '1.0.0'
 
 logger = logging.getLogger(__name__)
 
@@ -126,7 +129,10 @@ class GitHub(object):
         for k, v in data.items():
             if len(v) == 1:
                 data[k] = v[0]
-        return data.get('access_token', None)
+        token = data.get(b'access_token', None)
+        if token is not None:
+            token = token.decode('ascii')
+        return token
 
     def _handle_invalid_response(self):
         pass
@@ -160,11 +166,9 @@ class GitHub(object):
 
         status_code = str(response.status_code)
 
-        if status_code.startswith('4'):
+        if not status_code.startswith('2'):
             raise GitHubError(response)
 
-        assert status_code.startswith('2')
-
         if response.headers['Content-Type'].startswith('application/json'):
             return response.json()
         else:
